@@ -77,11 +77,11 @@ function show_step1()
 [v-cloak] {
   display: none !important;
 }
-.items { padding: 10px; border: 1px solid #FFF; }
-.item { padding: 6px 12px; font-weight: bold; border-bottom: 1px dotted #DDD; }
+.items { padding: 10px; border: 1px solid var(--border); }
+.item { padding: 6px 12px; font-weight: bold; border-bottom: 1px dotted var(--border); }
 .item:last-child { border-bottom: none; }
-.item:nth-child(even) { background-color: #FFF; }
-.item:nth-child(odd) { background-color: #F9F9F9; }
+.item:nth-child(even) { background-color: var(--background); }
+.item:nth-child(odd) { background-color: var(--secondary); }
 .item > img { margin-right: 10px; }
 </style>
 
