@@ -61,6 +61,7 @@ class snmpwalk extends Base {
 
         $oid_args = (!empty($snmp_args['oid'])) ? " --oid=" . escapeshellarg($snmp_args['oid']) : '';
 
+        // Base command
         $command = $script_dir . "/start_snmpwalk_job.sh " . 
          " --device_address=" . escapeshellarg($snmp_args['device_address']) .
          " --device_port=" . escapeshellarg($snmp_args['device_port']) .
@@ -72,6 +73,21 @@ class snmpwalk extends Base {
          $snmp_v2_args .
          $snmp_v3_args;
 
+        // Test SNMP connectivity first
+        exec($command . " --verify-only", $test_output, $test_exit_code);
+
+        if ($test_exit_code != 0) {
+            http_response_code(400);
+            header('Content-Type: application/json');
+            echo json_encode([
+                'error' => true,
+                'message' => 'SNMP connectivity test failed',
+                'details' => implode("\n", $test_output)
+            ]);
+            return;
+        }
+
+        // If test passes, proceed with the full snmpwalk
         $result = exec($command);
     }
 
