@@ -11,7 +11,7 @@ grab_request_vars();
 check_prereqs();
 check_authentication();
 
-route_to_neptune();
+route_to_neptune(true);
 
 // Start the page
 do_page_start(array("page_title" => _('Home')), true);
