@@ -148,8 +148,17 @@ function fetch_multistack($args)
         sourceHeight: $('#{$args['container']}').height(),
         sourceWidth: $('#{$args['container']}').width(),
         filename: '{$filename}',
-        chartOptions: { chart: { spacing: [25, 25, 25, 25], marginRight: 30 },
-                        title: { text: '" . _("Multistacked Performance Graph") . "' }
+        chartOptions: { 
+            chart: { 
+                spacing: [25, 10, 25, 25],
+                marginRight: 30
+            },
+            legend: {
+                itemStyle: {
+                    'font-size': '8px',
+                    'width': '150'
+                }
+            }
         },
         buttons: { {$exporting_buttons}{$buttons} }
     },";
@@ -247,6 +256,11 @@ GRAPH;
                                 text: ""
                             },
                             labels: {
+                                align: "right",
+                                reserveSpace: true,
+                                style: {
+                                    fontSize: "10px",
+                                },
                                 formatter: function() {
                                     if (this.value % 1 != 0) {
                                         return this.value.toFixed(2) + "' . $uom . '";
