@@ -160,7 +160,7 @@ function fetch_timeline_perfdata($args)
     // show buttons if displaying a single metric
     $zoom_button_x = '-29';
     if ($show_thresh && $wc_enable) {
-        $buttons = "
+        $buttons = ",
                     Critical: {
                         _id: 'hc-critical-button',
                         _titleKey: 'critical',
