@@ -354,13 +354,13 @@ class adLDAPGroups {
     * @param bool $recursive Recursively get group members
     * @return array
     */
-    public function members($group, $recursive = NULL, $search = "")
+    public function members($group, $recursive = NULL, $search = "", $target_page = 1, $page_size = 50)
     {
         if (!$this->adldap->getLdapBind()){ return false; }
         if ($recursive === NULL){ $recursive = $this->adldap->getRecursiveGroups(); } // Use the default option if they haven't set it 
         // Search the directory for the members of a group
         $info = $this->info($group, array("member","cn"));
-        $users = $info[0]["member"];
+        $users = (isset($info[0]["member"])) ? $info[0]["member"] : '';
         if (!is_array($users)) {
             return false;   
         }
