@@ -1424,11 +1424,16 @@ function show_user_options($users, $revise) {
                     if (username == "") {
                         $(row).find('.username').addClass('form-error');
                         errors = true;
+                    } else if (!username.match(/^[a-zA-Z0-9._-]{3,30}$/)) {
+                        // Username contains invalid characters
+                        $(row).find('.username').addClass('form-error');
+                        errortext += '<?php echo encode_form_valq(_("Usernames can only contain letters, numbers, dots, underscores, and hyphens.")); ?><br/>';
+                        errors = true;
                     } else if ($.inArray(username, users) >= 0) {
                         // Username is already in use
                         $(row).find('.username').addClass('form-error');
                         if (!uerror) {
-                            errortext += '<strong><?php echo encode_form_valq(_("Username(s) already exist")); ?>.</strong> <?php echo encode_form_valq(_("Usernames must be unique")); ?>. ';
+                            errortext += '<?php echo encode_form_valq(_("Username(s) already exist")); ?>: ' + username + '<br/>';
                         }
                         errors = true;
                         uerror = true;
@@ -1437,9 +1442,18 @@ function show_user_options($users, $revise) {
                         $(row).find('.displayname').addClass('form-error');
                         errors = true;
                     }
-                    if ($(row).find('.email').val() == "") {
+                    
+                    var email = $(row).find('.email').val();
+                    if (email == "") {
                         $(row).find('.email').addClass('form-error');
                         errors = true;
+                    } else if (!email.match(/^[^\s@]+@[^\s@]+\.[^\s@]+$/)) {
+                        // Email format is invalid
+                        $(row).find('.email').addClass('form-error');
+                        if (errortext.indexOf('<?php echo encode_form_valq(_("Invalid email format")); ?>') < 0) {
+                            errortext += '<?php echo encode_form_valq(_("Invalid email format")); ?>: ' + email + '<br/>';
+                        }
+                        errors = true;
                     }
                 });
 
