@@ -233,8 +233,17 @@ function do_page() {
         <!-- Popular Wizards Section -->
         <?php if (is_authorized_to_configure_objects() && !is_readonly_user()) { ?>
         <h3 class="splash-page-title"><?php echo _("Popular Wizards"); ?></h3>
+        <?php if (is_trial_license() && is_trial_expired()) { ?>
+        <div class="alert alert-info">
+            <b><?php echo _("IMPORTANT"); ?></b>: <?php echo _("Configuration Wizards are not available with an expired trial."); ?> <?php echo _("To unlock this feature and continue using Nagios XI:"); ?>
+            <div style="margin-top: 15px;">
+                <a href="https://www.nagios.com/products/nagios-xi/pricing/" target="_blank" class="btn btn-sm btn-primary" style="margin-right: 10px;"><?php echo _("Purchase a License"); ?></a>
+                <a href="/nagiosxi/admin/license.php" class="btn btn-sm btn-default"><?php echo _("Enter License Key"); ?></a>
+            </div>
+        </div>
+        <?php } ?>
         <span class="splash-page-title-subtext"><?php echo _("Click a card to begin using one of our most popular "); ?><a href="<?php echo get_base_url() . "config/monitoringwizard.php"; ?>"><?php echo _("Configuration Wizards"); ?></a>.</span>
-        <div class="row splash-page-row">
+        <div class="row splash-page-row<?php echo (is_trial_license() && is_trial_expired()) ? ' wizards-disabled' : ''; ?>">
             <div class="col-sm-2">
                 <div class="material-card wizard-card">
                     <a href="<?php echo get_base_url(); ?>/config/monitoringwizard.php?update=1&nextstep=2&nsp=<?php echo get_nagios_session_protector_id();?>&wizard=s3" class="wizard-card-anchor">
@@ -284,7 +293,6 @@ function do_page() {
                 </div>
             </div>
         </div>
-        </div>
         <?php } ?>
 
 <?php else: ?>
@@ -517,8 +525,17 @@ function do_page() {
 
         <!-- Popular Wizards Section -->
         <h3 class="splash-page-title"><?php echo _("Popular Wizards"); ?></h3>
+        <?php if (is_trial_license() && is_trial_expired()) { ?>
+        <div class="alert alert-info">
+            <b><?php echo _("IMPORTANT"); ?></b>: <?php echo _("Configuration Wizards are not available with an expired trial."); ?> <?php echo _("To unlock this feature and continue using Nagios XI:"); ?>
+            <div style="margin-top: 15px;">
+                <a href="https://www.nagios.com/products/nagios-xi/pricing/" target="_blank" class="btn btn-sm btn-primary" style="margin-right: 10px;"><?php echo _("Purchase a License"); ?></a>
+                <a href="/nagiosxi/admin/license.php" class="btn btn-sm btn-default"><?php echo _("Enter License Key"); ?></a>
+            </div>
+        </div>
+        <?php } ?>
         <span class="splash-page-title-subtext"><?php echo _("Click a card to begin using one of our most popular "); ?><a href="<?php echo get_base_url() . "config/monitoringwizard.php"; ?>"><?php echo _("Configuration Wizards"); ?></a>.</span>
-        <div class="row splash-page-row">
+        <div class="row splash-page-row <?php echo (is_trial_license() && is_trial_expired()) ? 'wizards-disabled' : ''; ?>">
             <div class="col-sm-2">
                 <div class="material-card wizard-card">
                     <a href="<?php echo get_base_url(); ?>/config/monitoringwizard.php?update=1&nextstep=2&nsp=<?php echo get_nagios_session_protector_id();?>&wizard=s3" class="wizard-card-anchor">
