@@ -254,11 +254,11 @@ function do_page_start($opts = array(), $child = false, $vue = false, $skip_call
     }
 
     # Page Usage
-    $user_id = grab_array_var($_SESSION, 'user_id');
+    $user_id = grab_array_var($_SESSION, 'user_id', 0);
 
     # This depends on the "page".
     # V1 dashboards => dashboard['id']
-    $usage_page_id = grab_array_var($opts, 'usage_page_id', null);
+    $usage_page_id = (string) grab_array_var($opts, 'usage_page_id', null);
 
     # Request Args, with a bit of filtering to avoid "sensitive" information
     # auto-discovery => mode=...
