@@ -144,6 +144,24 @@ function send_email($opts, &$debug = null, $referer = "", $txt = false)
             $mailArgs['importance'] = "high";
         } 
 
+        // See if there is an attachment and add to the mail
+        if (isset($opts["attachment"])) {
+            $mailArgs['attachments'] = array();
+            if (is_array($opts["attachment"])) {
+                foreach ($opts["attachment"] as $aopt) {
+                    $mailArgs['attachments'][] = array(
+                        'path' => $aopt[0],
+                        'name' => $aopt[1]
+                    );
+                }
+            } else {
+                $mailArgs['attachments'][] = array(
+                    'path' => $opts["attachment"],
+                    'name' => ''
+                );
+            }
+        }
+        
         // Add reply-to based on whether or not we are processing inbound email
         if (get_option("mail_inbound_process", 0)) {
             $replyto = get_option("mail_inbound_replyto");
