@@ -3206,7 +3206,7 @@ function init_dashboards_v2_menu() {
 
             // Build opts safely; only add user-specific meta if we have a user id
             $opts = array(
-                "href" => "v2/dashboard.php?id=" . $dashboard_id,
+                "href" => "/nagiosxi/dashboards/v2/dashboard.php?id=" . $dashboard_id,
             );
             if ($current_user_id !== null && $row_id !== null) {
                 $opts["neptune-icon"] = get_user_meta($current_user_id, "icon-dashboard-" . $row_id);
@@ -3268,7 +3268,7 @@ function init_dashboards_v2_menu() {
 
             // Build opts; only add icon meta if user id exists
             $opts = array(
-                "href"  => "dashboard.php?id=" . grab_array_var($dashboard, "id", ""),
+                "href"  => "/nagiosxi/dashboards/dashboard.php?id=" . grab_array_var($dashboard, "id", ""),
                 "class" => "mydashboardlink" . $home,
             );
             if ($current_user_id !== null) {
