@@ -618,7 +618,7 @@ function init_language()
     } else {
         // Try user-specific and global default language from DB
         $udblang = get_user_meta(0, "default_language");
-        if (!empty($udlang)) {
+        if (!empty($udblang)) {
             $session_language = $udblang;
         } else {
             $dblang = get_option("default_language");
