@@ -92,13 +92,16 @@
             <div id="auth2">
                 <div class="row mb-2">
                     <div class="col-sm-6">
-                        <label for="snmpcommunity" class="form-label form-item-required"><?= _('SNMP Community') ?> <?= xi6_info_tooltip(_('The SNMP community string required used to to query the Windows machine.')) ?></label>
-                        <div class="input-group position-relative">
-                            <input type="text" name="snmpcommunity" id="snmpcommunity" value="<?= encode_form_val($snmpcommunity) ?>" class="form-control monitor rounded" placeholder="<?= _("Enter SNMP Community") ?>" required>
+                        <label for="snmpcommunity" class="form-label form-item-required"><?= _("SNMP Community") ?> <?= xi6_info_tooltip(_("The SNMP community string required used to to query the Windows machine.")) ?></label>
+                        <div class="input-group">
+                            <input type="password" name="snmpcommunity" id="snmpcommunity" value="<?= encode_form_val($snmpcommunity) ?>" class="form-control rounded-start" autocomplete="off" placeholder="<?= _("Enter SNMP Community") ?>" required>
+                            <button type="button" class="btn btn-outline-secondary btn-show-secret rounded-end tt-bind" id="password-secret" title="<?= _("Show") ?>">
+                                <span class="material-symbols-outlined md-22 md-pointer">Visibility</span>
+                            </button>
+                            <i id="snmpcommunity_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                             <div class="invalid-feedback">
                                 Please enter the SNMP Community
                             </div>
-                            <i id="snmpcommunity_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                         </div>
                     </div>
                 </div>
@@ -140,12 +143,15 @@
                 <div class="row mb-2">
                     <div class="col-sm-6">
                         <label for="snmpopts[v3_auth_password]" class="form-label form-item-required"><?= _('Authentication Password') ?> </label>
-                        <div class="input-group position-relative">
-                            <input type="text" name="snmpopts[v3_auth_password]" id="snmpopts[v3_auth_password]" value="<?= encode_form_val($snmpopts["v3_auth_password"]) ?>" class="form-control monitor rounded authPriv-enable authNoPriv-enable noAuthNoPriv-disable" placeholder="<?= _("Enter Authentication Password") ?>" required>
+                        <div class="input-group">
+                            <input type="password" name="snmpopts[v3_auth_password]" id="snmpopts[v3_auth_password]" value="<?= encode_form_val($snmpopts["v3_auth_password"]) ?>" class="form-control rounded-start authPriv-enable authNoPriv-enable noAuthNoPriv-disable" autocomplete="off" placeholder="<?= _("Enter Authentication Password") ?>" required>
+                            <button type="button" class="btn btn-outline-secondary btn-show-secret rounded-end tt-bind" id="password-secret" title="<?= _("Show") ?>">
+                                <span class="material-symbols-outlined md-22 md-pointer">Visibility</span>
+                            </button>
+                            <i id="snmpopts_v3_auth_password_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                             <div class="invalid-feedback">
                                 Please enter the Authentication Password
                             </div>
-                            <i id="snmpopts_v3_auth_password_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                         </div>
                     </div>
                 </div>
@@ -169,12 +175,15 @@
                 <div class="row mb-2">
                     <div class="col-sm-6">
                         <label for="snmpopts[v3_privacy_password]" class="form-label form-item-required"><?= _('Privacy Password') ?> </label>
-                        <div class="input-group position-relative">
-                            <input type="text" name="snmpopts[v3_privacy_password]" id="snmpopts[v3_privacy_password]" value="<?= encode_form_val($snmpopts["v3_privacy_password"]) ?>" class="form-control monitor rounded authPriv-enable authNoPriv-disable noAuthNoPriv-disable" placeholder="<?= _("Enter Privacy Password") ?>" required>
+                        <div class="input-group">
+                            <input type="password" name="snmpopts[v3_privacy_password]" id="snmpopts[v3_privacy_password]" value="<?= encode_form_val($snmpopts["v3_privacy_password"]) ?>" class="form-control rounded-start authPriv-enable authNoPriv-disable noAuthNoPriv-disable" autocomplete="off" placeholder="<?= _("Enter Privacy Password") ?>" required>
+                            <button type="button" class="btn btn-outline-secondary btn-show-secret rounded-end tt-bind" id="password-secret" title="<?= _("Show") ?>">
+                                <span class="material-symbols-outlined md-22 md-pointer">Visibility</span>
+                            </button>
+                            <i id="snmpopts_v3_privacy_password_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                             <div class="invalid-feedback">
                                 Please enter the Privacy Password
                             </div>
-                            <i id="snmpopts_v3_privacy_password_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                         </div>
                     </div>
                 </div>
