@@ -201,7 +201,7 @@
                             <option value="name" <?= is_selected($interface_reference_style, "name"); ?>><?= _("Port Name"); ?></option>
                             <option value="descr" <?= is_selected($interface_reference_style, "descr"); ?>><?= _("Port Description"); ?></option>
                             <!--<option value="eth" <?= is_selected($interface_reference_style, "eth"); ?>><?= _("Port Physical Address"); ?></option>-->
-                            <option value="type" <?= is_selected($interface_reference_style, "type"); ?>><?= _("Port Type"); ?></option>
+                            <!--<option value="type" <?= is_selected($interface_reference_style, "type"); ?>><?= _("Port Type"); ?></option>-->
                         </select>
                     </div>
                 </div>
