@@ -83,12 +83,15 @@
             <div class="row mb-2">
                 <div class="col-sm-6">
                     <label for="snmpcommunity" class="form-label form-item-required"><?= _('SNMP Community') ?> <?= xi6_info_tooltip(_('The SNMP community string required to query the device')) ?></label>
-                    <div class="input-group position-relative">
-                        <input type="text" name="snmpcommunity" id="snmpcommunity" value="<?= encode_form_val($snmpcommunity) ?>" class="form-control form-control-sm monitor rounded" placeholder="<?= _("Enter SNMP Community") ?>" required >
+                    <div class="input-group">
+                        <input type="password" name="snmpcommunity" id="snmpcommunity" value="<?= encode_form_val($snmpcommunity) ?>" class="form-control rounded-start" autocomplete="off" placeholder="<?= _("Enter SNMP Community") ?>" required >
+                        <button type="button" class="btn btn-outline-secondary btn-show-secret rounded-end tt-bind" id="password-secret" title="<?= _("Show") ?>">
+                            <span class="material-symbols-outlined md-22 md-pointer">Visibility</span>
+                            <i id="snmpcommunity_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
+                        </button>
                         <div class="invalid-feedback">
                             <?= _("Please enter the SNMP Community") ?>
                         </div>
-                        <i id="snmpcommunity_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                     </div>
                 </div>
             </div>
@@ -131,12 +134,15 @@
             <div class="row mb-2">
                 <div class="col-sm-6">
                     <label for="serviceargs[v3_auth_password]" class="form-label form-item-required"><?= _('Authentication Password') ?> </label>
-                    <div class="input-group position-relative">
-                        <input type="text" name="serviceargs[v3_auth_password]" id="serviceargs[v3_auth_password]" value="<?= encode_form_val($serviceargs['v3_auth_password']) ?>" class="form-control form-control-sm monitor rounded noAuthNoPriv-disable" placeholder="<?= _("Enter Authentication Password") ?>" >
+                    <div class="input-group">
+                        <input type="password" name="serviceargs[v3_auth_password]" id="serviceargs[v3_auth_password]" value="<?= encode_form_val($serviceargs['v3_auth_password']) ?>" class="form-control rounded-start noAuthNoPriv-disable" autocomplete="off" placeholder="<?= _("Enter Authentication Password") ?>" >
+                        <button type="button" class="btn btn-outline-secondary btn-show-secret rounded-end tt-bind" id="password-secret" title="<?= _("Show") ?>">
+                            <span class="material-symbols-outlined md-22 md-pointer">Visibility</span>
+                            <i id="serviceargs_v3_auth_password_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
+                        </button>
                         <div class="invalid-feedback">
                             <?= _("Please enter the Password") ?>
                         </div>
-                        <i id="serviceargs_v3_auth_password_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                     </div>
                 </div>
             </div>
@@ -162,12 +168,15 @@
             <div class="row mb-2">
                 <div class="col-sm-6">
                     <label for="serviceargs[v3_privacy_password]" class="form-label form-item-required"><?= _('Privacy Password') ?> </label>
-                    <div class="input-group position-relative">
-                        <input type="text" name="serviceargs[v3_privacy_password]" id="serviceargs[v3_privacy_password]" value="<?= encode_form_val($serviceargs['v3_privacy_password']) ?>" class="form-control form-control-sm monitor rounded noAuthNoPriv-disable" placeholder="<?= _("Enter Privacy Password") ?>" >
+                    <div class="input-group">
+                        <input type="password" name="serviceargs[v3_privacy_password]" id="serviceargs[v3_privacy_password]" value="<?= encode_form_val($serviceargs['v3_privacy_password']) ?>" class="form-control rounded-start noAuthNoPriv-disable" autocomplete="off" placeholder="<?= _("Enter Privacy Password") ?>" >
+                        <button type="button" class="btn btn-outline-secondary btn-show-secret rounded-end tt-bind" id="password-secret" title="<?= _("Show") ?>">
+                            <span class="material-symbols-outlined md-22 md-pointer">Visibility</span>
+                            <i id="serviceargs_v3_privacy_password_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
+                        </button>
                         <div class="invalid-feedback">
                             <?= _("Please enter the Privacy Password") ?>
                         </div>
-                        <i id="serviceargs_v3_privacy_password_Alert" class="visually-hidden position-absolute top-0 start-100 translate-middle icon icon-circle color-ok icon-size-status"></i>
                     </div>
                 </div>
             </div>
